@@ -280,7 +280,7 @@ class Dataset(object):
         for t in self.tables:
             t.tableSchema.foreignKeys = [
                 fk for fk in t.tableSchema.foreignKeys
-                if (fk.reference.resource != table.url or
+                if (fk.reference.resource != table.url or  # noqa: W504
                     (not set(str(c) for c in fk.reference.columnReference).intersection(cols)))]
 
         # Remove primary key constraints:
@@ -371,7 +371,8 @@ class Dataset(object):
 
     @property
     def bibpath(self):
-        return self.directory.joinpath(self.properties.get('dc:source', 'sources.bib'))
+        # Specifying "dc:source": "" means lookup the default location.
+        return self.directory.joinpath(self.properties.get('dc:source') or 'sources.bib')
 
     def validate(self, log=None, validators=None):
         validators = validators or []
@@ -421,12 +422,24 @@ class Dataset(object):
                         'This may cause problems with "cldf createdb"'))
 
             # FIXME: check whether table.common_props['dc:conformsTo'] is in validators!
-            validators_ = []
+            validators_, propertyUrls, colnames = [], set(), set()
             for col in table.tableSchema.columns:
+                if col.header in colnames:
+                    log_or_raise(
+                        'Duplicate column name in table schema: {} {}'.format(
+                            table.url, col.header),
+                        log=log)
+                colnames.add(col.header)
                 if col.propertyUrl:
                     col_uri = col.propertyUrl.uri
                     try:
                         TERMS.is_cldf_uri(col_uri)
+                        if col_uri in propertyUrls:
+                            log_or_raise(
+                                'Duplicate CLDF property in table schema: {} {}'.format(
+                                    table.url, col_uri),
+                                log=log)
+                        propertyUrls.add(col_uri)
                     except ValueError:
                         success = False
                         log_or_raise('invalid CLDF URI: {0}'.format(col_uri), log=log)
